IStyle class

Constructors

IStyle({String style = 'dark', String? themeName, String? loadingStickmanColor, String? loadingBackgroundColor, String? loadingTextColor})

Properties

hashCode int
The hash code for this object.
no setterinherited
loadingBackgroundColor String?
final
loadingStickmanColor String?
final
loadingTextColor String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style String
final
themeName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited