KinesteXViewBuilder class

Constructors

KinesteXViewBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build({required String apiKey, required String companyName, required String userId, required String url, IStyle? style, Map<String, dynamic> data = const {}, UserDetails? user, Map<String, dynamic>? customParams, required ValueNotifier<bool> isLoading, required ValueNotifier<bool> showKinesteX, required dynamic onMessageReceived(WebViewMessage), String? updatedExercise}) Widget
colorFromHex(String hex) Color