PlanDay class
PlanDay represents a day within a plan level
- Annotations
Constructors
-
PlanDay({required String title, required String description, List<
WorkoutSummary> ? workouts, Map<String, dynamic> ? rawJSON}) -
const
-
PlanDay.fromJson(Map<
String, dynamic> json) -
factory
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rawJSON
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
-
workouts
→ List<
WorkoutSummary> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited