PlanLevel class

PlanLevel defines a specific level within a workout plan

Annotations

Constructors

PlanLevel({required String title, required String description, required Map<String, PlanDay> days, Map<String, dynamic>? rawJSON})
const
PlanLevel.fromJson(Map<String, dynamic> json)
factory

Properties

days Map<String, PlanDay>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
rawJSON Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited