WorkoutSummary class

WorkoutSummary provides basic information about a workout

Annotations

Constructors

WorkoutSummary({required String id, required String imgURL, required String title, double? calories, required int totalMinutes, Map<String, dynamic>? rawJSON})
const
WorkoutSummary.fromJson(Map<String, dynamic> json)
factory

Properties

calories double?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
imgURL String
final
rawJSON Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
totalMinutes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited