WorkoutSequenceExercise class
Constructors
- WorkoutSequenceExercise({required String exerciseId, int? reps, int? duration, bool includeRestPeriod = false, int restDuration = 0})
-
const
- WorkoutSequenceExercise.fromJson(String source)
-
factory
-
WorkoutSequenceExercise.fromMap(Map<
String, dynamic> map) -
factory
Properties
- duration → int?
-
final
- exerciseId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeRestPeriod → bool
-
final
- reps → int?
-
final
- restDuration → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? exerciseId, int? reps, int? duration, bool? includeRestPeriod, int? restDuration}) → WorkoutSequenceExercise -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override